export interface SimpleLocalStorageCache {
    /**
     * get a value from cache by key
     */
    get: (key: string) => Promise<string | undefined>;
    /**
     * set a value to cache for key
     */
    set: (key: string, value: string | undefined, options?: {
        secondsUntilExpiration?: number;
    }) => Promise<void>;
    /**
     * list all valid keys in cache
     */
    keys: () => Promise<string[]>;
}
/**
 * a utility function for deciding whether a record is valid
 */
export declare const isRecordExpired: ({ expiresAtMse, }: {
    expiresAtMse: number | null;
}) => boolean;
export declare const createCache: ({ namespace, defaultSecondsUntilExpiration, }: {
    /**
     * specifies the namespace under which cached items will be persisted in the localstorage
     *
     * for example
     * - namespace = 'likes' && key = 'donuts' => localstorage cache key = `cache:likes:donuts`
     */
    namespace: string;
    /**
     * specifies the default number of seconds until a record is considered expired
     *
     * note
     * - use `null` for "never expire"
     */
    defaultSecondsUntilExpiration?: number | null | undefined;
}) => SimpleLocalStorageCache;
